@@ -21,6 +21,7 @@ import base64
 import json
 import sys
 from copy import deepcopy
+from datetime import datetime, timedelta
 from typing import TYPE_CHECKING, Any
 from unittest import mock
 from unittest.mock import Mock, PropertyMock
@@ -29,10 +30,12 @@ import pytest
 from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives import serialization
 from cryptography.hazmat.primitives.asymmetric import rsa
+from requests.exceptions import ConnectionError, HTTPError
 
-from airflow.exceptions import AirflowOptionalProviderFeatureException
 from airflow.models import Connection
+from airflow.providers.common.compat.sdk import AirflowOptionalProviderFeatureException
 from airflow.providers.snowflake.hooks.snowflake import SnowflakeHook
+from airflow.utils import timezone
 
 if TYPE_CHECKING:
     from pathlib import Path
@@ -106,7 +109,7 @@ def base64_encoded_encrypted_private_key(encrypted_temporary_private_key: Path)
 
 class TestPytestSnowflakeHook:
     @pytest.mark.parametrize(
-        "connection_kwargs,expected_uri,expected_conn_params",
+        ("connection_kwargs", "expected_uri", "expected_conn_params"),
         [
             (
                 BASE_CONNECTION_KWARGS,
@@ -367,7 +370,7 @@ class TestPytestSnowflakeHook:
     ):
         with mock.patch.dict("os.environ", AIRFLOW_CONN_TEST_CONN=Connection(**connection_kwargs).get_uri()):
             assert SnowflakeHook(snowflake_conn_id="test_conn").get_uri() == expected_uri
-            assert SnowflakeHook(snowflake_conn_id="test_conn")._get_conn_params == expected_conn_params
+            assert SnowflakeHook(snowflake_conn_id="test_conn")._get_conn_params() == expected_conn_params
 
     def test_get_conn_params_should_support_private_auth_in_connection(
         self, base64_encoded_encrypted_private_key: Path
@@ -385,7 +388,7 @@ class TestPytestSnowflakeHook:
             },
         }
         with mock.patch.dict("os.environ", AIRFLOW_CONN_TEST_CONN=Connection(**connection_kwargs).get_uri()):
-            assert "private_key" in SnowflakeHook(snowflake_conn_id="test_conn")._get_conn_params
+            assert "private_key" in SnowflakeHook(snowflake_conn_id="test_conn")._get_conn_params()
 
     @pytest.mark.parametrize("include_params", [True, False])
     def test_hook_param_beats_extra(self, include_params):
@@ -408,7 +411,7 @@ class TestPytestSnowflakeHook:
             assert hook_params != extras
             assert SnowflakeHook(
                 snowflake_conn_id="test_conn", **(hook_params if include_params else {})
-            )._get_conn_params == {
+            )._get_conn_params() == {
                 "user": None,
                 "password": "",
                 "application": "AIRFLOW",
@@ -437,7 +440,7 @@ class TestPytestSnowflakeHook:
             ).get_uri(),
         ):
             assert list(extras.values()) != list(extras_prefixed.values())
-            assert SnowflakeHook(snowflake_conn_id="test_conn")._get_conn_params == {
+            assert SnowflakeHook(snowflake_conn_id="test_conn")._get_conn_params() == {
                 "user": None,
                 "password": "",
                 "application": "AIRFLOW",
@@ -463,7 +466,7 @@ class TestPytestSnowflakeHook:
             },
         }
         with mock.patch.dict("os.environ", AIRFLOW_CONN_TEST_CONN=Connection(**connection_kwargs).get_uri()):
-            assert "private_key" in SnowflakeHook(snowflake_conn_id="test_conn")._get_conn_params
+            assert "private_key" in SnowflakeHook(snowflake_conn_id="test_conn")._get_conn_params()
 
     def test_get_conn_params_should_support_private_auth_with_unencrypted_key(
         self, unencrypted_temporary_private_key
@@ -481,16 +484,16 @@ class TestPytestSnowflakeHook:
             },
         }
         with mock.patch.dict("os.environ", AIRFLOW_CONN_TEST_CONN=Connection(**connection_kwargs).get_uri()):
-            assert "private_key" in SnowflakeHook(snowflake_conn_id="test_conn")._get_conn_params
+            assert "private_key" in SnowflakeHook(snowflake_conn_id="test_conn")._get_conn_params()
         connection_kwargs["password"] = ""
         with mock.patch.dict("os.environ", AIRFLOW_CONN_TEST_CONN=Connection(**connection_kwargs).get_uri()):
-            assert "private_key" in SnowflakeHook(snowflake_conn_id="test_conn")._get_conn_params
+            assert "private_key" in SnowflakeHook(snowflake_conn_id="test_conn")._get_conn_params()
         connection_kwargs["password"] = _PASSWORD
         with (
             mock.patch.dict("os.environ", AIRFLOW_CONN_TEST_CONN=Connection(**connection_kwargs).get_uri()),
             pytest.raises(TypeError, match="Password was given but private key is not encrypted."),
         ):
-            SnowflakeHook(snowflake_conn_id="test_conn")._get_conn_params
+            SnowflakeHook(snowflake_conn_id="test_conn")._get_conn_params()
 
     def test_get_conn_params_should_fail_on_invalid_key(self):
         connection_kwargs = {
@@ -512,10 +515,7 @@ class TestPytestSnowflakeHook:
             SnowflakeHook(snowflake_conn_id="test_conn").get_conn()
 
     @mock.patch("requests.post")
-    @mock.patch(
-        "airflow.providers.snowflake.hooks.snowflake.SnowflakeHook._get_conn_params",
-        new_callable=PropertyMock,
-    )
+    @mock.patch("airflow.providers.snowflake.hooks.snowflake.SnowflakeHook._get_conn_params")
     def test_get_conn_params_should_support_oauth(self, mock_get_conn_params, requests_post):
         requests_post.return_value = Mock(
             status_code=200,
@@ -544,7 +544,7 @@ class TestPytestSnowflakeHook:
         mock_get_conn_params.return_value = connection_kwargs
         with mock.patch.dict("os.environ", AIRFLOW_CONN_TEST_CONN=Connection(**connection_kwargs).get_uri()):
             hook = SnowflakeHook(snowflake_conn_id="test_conn")
-            conn_params = hook._get_conn_params
+            conn_params = hook._get_conn_params()
 
         conn_params_keys = conn_params.keys()
         conn_params_extra = conn_params.get("extra", {})
@@ -563,7 +563,6 @@ class TestPytestSnowflakeHook:
     @mock.patch("requests.post")
     @mock.patch(
         "airflow.providers.snowflake.hooks.snowflake.SnowflakeHook._get_conn_params",
-        new_callable=PropertyMock,
     )
     def test_get_conn_params_should_support_oauth_with_token_endpoint(
         self, mock_get_conn_params, requests_post
@@ -596,7 +595,7 @@ class TestPytestSnowflakeHook:
         mock_get_conn_params.return_value = connection_kwargs
         with mock.patch.dict("os.environ", AIRFLOW_CONN_TEST_CONN=Connection(**connection_kwargs).get_uri()):
             hook = SnowflakeHook(snowflake_conn_id="test_conn")
-            conn_params = hook._get_conn_params
+            conn_params = hook._get_conn_params()
 
         conn_params_keys = conn_params.keys()
         conn_params_extra = conn_params.get("extra", {})
@@ -616,7 +615,6 @@ class TestPytestSnowflakeHook:
     @mock.patch("requests.post")
     @mock.patch(
         "airflow.providers.snowflake.hooks.snowflake.SnowflakeHook._get_conn_params",
-        new_callable=PropertyMock,
     )
     def test_get_conn_params_should_support_oauth_with_client_credentials(
         self, mock_get_conn_params, requests_post
@@ -649,7 +647,7 @@ class TestPytestSnowflakeHook:
         mock_get_conn_params.return_value = connection_kwargs
         with mock.patch.dict("os.environ", AIRFLOW_CONN_TEST_CONN=Connection(**connection_kwargs).get_uri()):
             hook = SnowflakeHook(snowflake_conn_id="test_conn")
-            conn_params = hook._get_conn_params
+            conn_params = hook._get_conn_params()
 
         conn_params_keys = conn_params.keys()
         conn_params_extra = conn_params.get("extra", {})
@@ -686,7 +684,7 @@ class TestPytestSnowflakeHook:
 
         with mock.patch.dict("os.environ", AIRFLOW_CONN_TEST_CONN=Connection(**connection_kwargs).get_uri()):
             hook = SnowflakeHook(snowflake_conn_id="test_conn")
-            conn_params = hook._get_conn_params
+            conn_params = hook._get_conn_params()
 
         # Check AzureBaseHook initialization and get_token call args
         mock_connection_class.get.assert_called_once_with(azure_conn_id)
@@ -704,6 +702,44 @@ class TestPytestSnowflakeHook:
         assert "region" in conn_params
         assert "account" in conn_params
 
+    @mock.patch("requests.post")
+    def test_get_conn_params_include_scope(self, mock_requests_post):
+        """
+        Verify that `_get_conn_params` includes the `scope` field when it is present
+        in the connection extras.
+        """
+        mock_requests_post.return_value = Mock(
+            status_code=200,
+            json=lambda: {
+                "access_token": "dummy",
+                "expires_in": 600,
+                "token_type": "Bearer",
+                "username": "test_user",
+            },
+        )
+
+        connection_kwargs = {
+            **BASE_CONNECTION_KWARGS,
+            "login": "test_client_id",
+            "password": "test_client_secret",
+            "extra": {
+                "account": "airflow",
+                "authenticator": "oauth",
+                "grant_type": "client_credentials",
+                "scope": "default",
+            },
+        }
+
+        with mock.patch.dict(
+            "os.environ",
+            {"AIRFLOW_CONN_TEST_CONN": Connection(**connection_kwargs).get_uri()},
+        ):
+            hook = SnowflakeHook(snowflake_conn_id="test_conn")
+            params = hook._get_conn_params()
+        mock_requests_post.assert_called_once()
+        assert "scope" in params
+        assert params["scope"] == "default"
+
     def test_should_add_partner_info(self):
         with mock.patch.dict(
             "os.environ",
@@ -711,7 +747,8 @@ class TestPytestSnowflakeHook:
             AIRFLOW_SNOWFLAKE_PARTNER="PARTNER_NAME",
         ):
             assert (
-                SnowflakeHook(snowflake_conn_id="test_conn")._get_conn_params["application"] == "PARTNER_NAME"
+                SnowflakeHook(snowflake_conn_id="test_conn")._get_conn_params()["application"]
+                == "PARTNER_NAME"
             )
 
     def test_get_conn_should_call_connect(self):
@@ -723,7 +760,7 @@ class TestPytestSnowflakeHook:
         ):
             hook = SnowflakeHook(snowflake_conn_id="test_conn")
             conn = hook.get_conn()
-            mock_connector.connect.assert_called_once_with(**hook._get_conn_params)
+            mock_connector.connect.assert_called_once_with(**hook._get_conn_params())
             assert mock_connector.connect.return_value == conn
 
     def test_get_sqlalchemy_engine_should_support_pass_auth(self):
@@ -838,7 +875,7 @@ class TestPytestSnowflakeHook:
                 authenticator="TEST_AUTH",
                 session_parameters={"AA": "AAA"},
             )
-            assert hook._get_conn_params == {
+            assert hook._get_conn_params() == {
                 "account": "TEST_ACCOUNT",
                 "application": "AIRFLOW",
                 "authenticator": "TEST_AUTH",
@@ -857,7 +894,7 @@ class TestPytestSnowflakeHook:
             )
 
     @pytest.mark.parametrize(
-        "sql,expected_sql,expected_query_ids",
+        ("sql", "expected_sql", "expected_query_ids"),
         [
             ("select * from table", ["select * from table"], ["uuid"]),
             (
@@ -1008,7 +1045,7 @@ class TestPytestSnowflakeHook:
         hook.get_openlineage_database_info = lambda x: mock.MagicMock(authority="auth", scheme="scheme")
 
         expected_err = (
-            "OpenLineage provider version `1.99.0` is lower than required `2.3.0`, "
+            "OpenLineage provider version `1.99.0` is lower than required `2.5.0`, "
             "skipping function `emit_openlineage_events_for_snowflake_queries` execution"
         )
         with pytest.raises(AirflowOptionalProviderFeatureException, match=expected_err):
@@ -1030,7 +1067,7 @@ class TestPytestSnowflakeHook:
             session = hook.get_snowpark_session()
             assert session == mock_session
 
-            mock_session_builder.configs.assert_called_once_with(hook._get_conn_params)
+            mock_session_builder.configs.assert_called_once_with(hook._get_conn_params())
 
             # Verify that update_query_tag was called with the expected tag dictionary
             mock_session.update_query_tag.assert_called_once_with(
@@ -1063,6 +1100,7 @@ class TestPytestSnowflakeHook:
             },
             headers={"Content-Type": "application/x-www-form-urlencoded"},
             auth=basic_auth,
+            timeout=30,
         )
 
     @mock.patch("airflow.providers.snowflake.hooks.snowflake.HTTPBasicAuth")
@@ -1091,8 +1129,114 @@ class TestPytestSnowflakeHook:
             },
             headers={"Content-Type": "application/x-www-form-urlencoded"},
             auth=basic_auth,
+            timeout=30,
         )
 
+    @mock.patch("airflow.providers.snowflake.hooks.snowflake.timezone.utcnow")
+    @mock.patch("requests.post")
+    def test_get_oauth_token_retries_and_succeeds(self, requests_post, mock_timezone_utcnow):
+
+        # Freeze time to prevent access token expiration.
+        t0 = datetime(2025, 1, 1, 12, 0, tzinfo=timezone.utc)
+        mock_timezone_utcnow.side_effect = [t0, t0]
+
+        requests_post.side_effect = [
+            ConnectionError("temporary network error"),
+            Mock(
+                status_code=200,
+                json=lambda: {"access_token": "retry_token", "expires_in": 600},
+                raise_for_status=lambda: None,
+            ),
+        ]
+
+        connection_kwargs = {
+            **BASE_CONNECTION_KWARGS,
+            "login": "client_id",
+            "password": "client_secret",
+            "extra": {
+                "account": "airflow",
+                "authenticator": "oauth",
+                "grant_type": "refresh_token",
+                "refresh_token": "secret_token",
+            },
+        }
+
+        with mock.patch.dict(
+            "os.environ",
+            {"AIRFLOW_CONN_TEST_CONN": Connection(**connection_kwargs).get_uri()},
+        ):
+            hook = SnowflakeHook(snowflake_conn_id="test_conn")
+            token = hook.get_oauth_token()
+
+        # Should retry.
+        assert token == "retry_token"
+        assert requests_post.call_count == 2
+
+    @mock.patch("airflow.providers.snowflake.hooks.snowflake.requests.post")
+    def test_get_oauth_token_does_not_retry_on_client_error(self, requests_post):
+
+        response = Mock(status_code=401)
+        http_error = HTTPError(response=response)
+
+        mock_response = Mock()
+        mock_response.raise_for_status.side_effect = http_error
+
+        requests_post.return_value = mock_response
+
+        connection_kwargs = {
+            **BASE_CONNECTION_KWARGS,
+            "login": "client_id",
+            "password": "client_secret",
+            "extra": {
+                "account": "airflow",
+                "authenticator": "oauth",
+                "grant_type": "refresh_token",
+                "refresh_token": "secret_token",
+            },
+        }
+
+        with mock.patch.dict(
+            "os.environ",
+            {"AIRFLOW_CONN_TEST_CONN": Connection(**connection_kwargs).get_uri()},
+        ):
+            hook = SnowflakeHook(snowflake_conn_id="test_conn")
+
+            with pytest.raises(HTTPError):
+                hook.get_oauth_token()
+
+        # Should not retry.
+        assert requests_post.call_count == 1
+
+    @mock.patch("airflow.providers.snowflake.hooks.snowflake.requests.post")
+    def test_get_oauth_token_fails_after_max_retries(self, requests_post):
+
+        # Always fail with retryable error.
+        requests_post.side_effect = ConnectionError("persistent network failure")
+
+        connection_kwargs = {
+            **BASE_CONNECTION_KWARGS,
+            "login": "client_id",
+            "password": "client_secret",
+            "extra": {
+                "account": "airflow",
+                "authenticator": "oauth",
+                "grant_type": "refresh_token",
+                "refresh_token": "secret_token",
+            },
+        }
+
+        with mock.patch.dict(
+            "os.environ",
+            {"AIRFLOW_CONN_TEST_CONN": Connection(**connection_kwargs).get_uri()},
+        ):
+            hook = SnowflakeHook(snowflake_conn_id="test_conn")
+
+            with pytest.raises(ConnectionError):
+                hook.get_oauth_token()
+
+        # Stop after the third attempt.
+        assert requests_post.call_count == 3
+
     def test_get_azure_oauth_token(self, mocker):
         """Test get_azure_oauth_token method gets token from provided connection id"""
         azure_conn_id = "azure_test_conn"
@@ -1110,22 +1254,22 @@ class TestPytestSnowflakeHook:
         mock_azure_base_hook.get_token.assert_called_once_with(SnowflakeHook.default_azure_oauth_scope)
         assert token == mock_azure_token
 
-    def test_get_azure_oauth_token_expect_failure_on_get_token(self, mocker):
-        """Test get_azure_oauth_token method gets token from provided connection id"""
+    def test_get_azure_oauth_token_expect_failure_on_older_azure_provider_package(self, mocker):
+        class MockAzureBaseHookOldVersion:
+            """Simulate an old version of AzureBaseHook where sdk_client is required."""
 
-        class MockAzureBaseHookWithoutGetToken:
-            def __init__(self):
+            def __init__(self, sdk_client, conn_id="azure_default"):
                 pass
 
         azure_conn_id = "azure_test_conn"
         mock_connection_class = mocker.patch("airflow.providers.snowflake.hooks.snowflake.Connection")
-        mock_connection_class.get.return_value.get_hook.return_value = MockAzureBaseHookWithoutGetToken()
+        mock_connection_class.get.return_value.get_hook = MockAzureBaseHookOldVersion
 
         hook = SnowflakeHook(snowflake_conn_id="mock_conn_id")
         with pytest.raises(
-            AttributeError,
+            AirflowOptionalProviderFeatureException,
             match=(
-                "'AzureBaseHook' object has no attribute 'get_token'. "
+                "Getting azure token is not supported.*"
                 "Please upgrade apache-airflow-providers-microsoft-azure>="
             ),
         ):
@@ -1133,3 +1277,272 @@ class TestPytestSnowflakeHook:
 
         # Check AzureBaseHook initialization
         mock_connection_class.get.assert_called_once_with(azure_conn_id)
+
+    @mock.patch("requests.post")
+    def test_get_oauth_token_with_scope(self, mock_requests_post):
+        """
+        Verify that `get_oauth_token` returns an access token and includes the
+        provided scope in the outgoing OAuth request payload.
+        """
+
+        mock_requests_post.return_value = Mock(
+            status_code=200,
+            json=lambda: {"access_token": "dummy_token", "expires_in": 600},
+        )
+
+        connection_kwargs = {
+            **BASE_CONNECTION_KWARGS,
+            "login": "client_id",
+            "password": "client_secret",
+            "extra": {
+                "account": "airflow",
+                "authenticator": "oauth",
+                "grant_type": "client_credentials",
+                "scope": "default",
+            },
+        }
+
+        with mock.patch.dict(
+            "os.environ",
+            {"AIRFLOW_CONN_TEST_CONN": Connection(**connection_kwargs).get_uri()},
+        ):
+            hook = SnowflakeHook(snowflake_conn_id="test_conn")
+            token = hook.get_oauth_token(grant_type="client_credentials")
+
+        assert token == "dummy_token"
+
+        called_data = mock_requests_post.call_args.kwargs["data"]
+
+        assert called_data["scope"] == "default"
+        assert called_data["grant_type"] == "client_credentials"
+
+    @mock.patch("requests.post")
+    def test_get_oauth_token_without_scope(self, mock_requests_post):
+        """
+        Verify that `get_oauth_token` returns an access token`
+        when no scope is defined in the connection extras.
+        """
+        mock_requests_post.return_value = Mock(
+            status_code=200,
+            json=lambda: {"access_token": "dummy_token", "expires_in": 600},
+        )
+
+        connection_kwargs = {
+            **BASE_CONNECTION_KWARGS,
+            "login": "client_id",
+            "password": "client_secret",
+            "extra": {"account": "airflow", "authenticator": "oauth", "grant_type": "client_credentials"},
+        }
+
+        with mock.patch.dict(
+            "os.environ",
+            {"AIRFLOW_CONN_TEST_CONN": Connection(**connection_kwargs).get_uri()},
+        ):
+            hook = SnowflakeHook(snowflake_conn_id="test_conn")
+            token = hook.get_oauth_token(grant_type="client_credentials")
+
+        assert token == "dummy_token"
+
+        called_data = mock_requests_post.call_args.kwargs["data"]
+
+        assert "scope" not in called_data
+        assert called_data["grant_type"] == "client_credentials"
+
+    @mock.patch("requests.post")
+    @mock.patch("airflow.providers.snowflake.hooks.snowflake.timezone.utcnow")
+    def test_oauth_token_refresh_after_expiry(self, mock_timezone_utcnow, mock_requests_post):
+        """
+        Ensure OAuth tokens are refreshed after expiry for a reused SnowflakeHook,
+        without mutating static connection parameters.
+        """
+
+        t0 = datetime(2025, 1, 1, 12, 0, tzinfo=timezone.utc)
+
+        # _get_valid_oauth_token calls utcnow twice per refresh:
+        #   1) validity check
+        #   2) issued_at
+        mock_timezone_utcnow.side_effect = [
+            t0,
+            t0,
+            t0 + timedelta(minutes=11),
+            t0 + timedelta(minutes=11),
+        ]
+
+        mock_requests_post.side_effect = [
+            Mock(
+                status_code=200,
+                json=lambda: {"access_token": "token1", "expires_in": 600},
+                raise_for_status=lambda: None,
+            ),
+            Mock(
+                status_code=200,
+                json=lambda: {"access_token": "token2", "expires_in": 600},
+                raise_for_status=lambda: None,
+            ),
+        ]
+
+        connection_kwargs = {
+            **BASE_CONNECTION_KWARGS,
+            "login": "client_id",
+            "password": "client_secret",
+            "extra": {
+                "account": "airflow",
+                "authenticator": "oauth",
+                "grant_type": "refresh_token",
+                "refresh_token": "secret_token",
+            },
+        }
+
+        with mock.patch.dict(
+            "os.environ",
+            {"AIRFLOW_CONN_TEST_CONN": Connection(**connection_kwargs).get_uri()},
+        ):
+            hook = SnowflakeHook(snowflake_conn_id="test_conn")
+            # First resolution (initial token)
+            conn_params_1 = hook._get_conn_params()
+
+            # Second resolution (after token expiry)
+            conn_params_2 = hook._get_conn_params()
+
+        # Token must be refreshed
+        assert conn_params_1["token"] == "token1"
+        assert conn_params_2["token"] == "token2"
+
+        # Static params must not change
+        assert {k: v for k, v in conn_params_1.items() if k != "token"} == {
+            k: v for k, v in conn_params_2.items() if k != "token"
+        }
+
+        # Ensure refresh actually happened
+        assert mock_requests_post.call_count == 2
+
+    def test_get_conn_params_with_proxy_host_only(self):
+        """Test proxy configuration with only host specified."""
+        connection_kwargs = deepcopy(BASE_CONNECTION_KWARGS)
+        connection_kwargs["extra"]["proxy_host"] = "proxy.example.com"
+
+        with mock.patch.dict("os.environ", AIRFLOW_CONN_TEST_CONN=Connection(**connection_kwargs).get_uri()):
+            hook = SnowflakeHook(snowflake_conn_id="test_conn")
+            conn_params = hook._get_conn_params()
+
+            assert conn_params["proxy_host"] == "proxy.example.com"
+            assert "proxy_port" not in conn_params
+            assert "proxy_user" not in conn_params
+            assert "proxy_password" not in conn_params
+
+    def test_get_conn_params_with_proxy_host_and_port(self):
+        """Test proxy configuration with host and port."""
+        connection_kwargs = deepcopy(BASE_CONNECTION_KWARGS)
+        connection_kwargs["extra"]["proxy_host"] = "proxy.example.com"
+        connection_kwargs["extra"]["proxy_port"] = "8080"
+
+        with mock.patch.dict("os.environ", AIRFLOW_CONN_TEST_CONN=Connection(**connection_kwargs).get_uri()):
+            hook = SnowflakeHook(snowflake_conn_id="test_conn")
+            conn_params = hook._get_conn_params()
+
+            assert conn_params["proxy_host"] == "proxy.example.com"
+            assert conn_params["proxy_port"] == 8080
+            assert "proxy_user" not in conn_params
+            assert "proxy_password" not in conn_params
+
+    def test_get_conn_params_with_proxy_port_as_int(self):
+        """Test proxy configuration with port as integer."""
+        connection_kwargs = deepcopy(BASE_CONNECTION_KWARGS)
+        connection_kwargs["extra"]["proxy_host"] = "proxy.example.com"
+        connection_kwargs["extra"]["proxy_port"] = 8080  # Integer instead of string
+
+        with mock.patch.dict("os.environ", AIRFLOW_CONN_TEST_CONN=Connection(**connection_kwargs).get_uri()):
+            hook = SnowflakeHook(snowflake_conn_id="test_conn")
+            conn_params = hook._get_conn_params()
+
+            assert conn_params["proxy_host"] == "proxy.example.com"
+            assert conn_params["proxy_port"] == 8080
+            assert isinstance(conn_params["proxy_port"], int)
+
+    def test_get_conn_params_with_proxy_full_config(self):
+        """Test proxy configuration with all parameters."""
+        connection_kwargs = deepcopy(BASE_CONNECTION_KWARGS)
+        connection_kwargs["extra"]["proxy_host"] = "proxy.example.com"
+        connection_kwargs["extra"]["proxy_port"] = "8080"
+        connection_kwargs["extra"]["proxy_user"] = "proxy_username"
+        connection_kwargs["extra"]["proxy_password"] = "proxy_password"
+
+        with mock.patch.dict("os.environ", AIRFLOW_CONN_TEST_CONN=Connection(**connection_kwargs).get_uri()):
+            hook = SnowflakeHook(snowflake_conn_id="test_conn")
+            conn_params = hook._get_conn_params()
+
+            assert conn_params["proxy_host"] == "proxy.example.com"
+            assert conn_params["proxy_port"] == 8080
+            assert conn_params["proxy_user"] == "proxy_username"
+            assert conn_params["proxy_password"] == "proxy_password"
+
+    def test_get_conn_params_with_proxy_backcompat_prefix(self):
+        """Test proxy configuration with backcompat prefix."""
+        connection_kwargs = deepcopy(BASE_CONNECTION_KWARGS)
+        connection_kwargs["extra"]["extra__snowflake__proxy_host"] = "proxy.example.com"
+        connection_kwargs["extra"]["extra__snowflake__proxy_port"] = "8080"
+        connection_kwargs["extra"]["extra__snowflake__proxy_user"] = "proxy_username"
+        connection_kwargs["extra"]["extra__snowflake__proxy_password"] = "proxy_password"
+
+        with mock.patch.dict("os.environ", AIRFLOW_CONN_TEST_CONN=Connection(**connection_kwargs).get_uri()):
+            hook = SnowflakeHook(snowflake_conn_id="test_conn")
+            conn_params = hook._get_conn_params()
+
+            assert conn_params["proxy_host"] == "proxy.example.com"
+            assert conn_params["proxy_port"] == 8080
+            assert conn_params["proxy_user"] == "proxy_username"
+            assert conn_params["proxy_password"] == "proxy_password"
+
+    def test_get_conn_with_proxy_should_call_connect(self):
+        """Test that proxy parameters are passed to connector.connect()."""
+        connection_kwargs = deepcopy(BASE_CONNECTION_KWARGS)
+        connection_kwargs["extra"]["proxy_host"] = "proxy.example.com"
+        connection_kwargs["extra"]["proxy_port"] = "8080"
+        connection_kwargs["extra"]["proxy_user"] = "proxy_user"
+        connection_kwargs["extra"]["proxy_password"] = "proxy_pass"
+
+        with (
+            mock.patch.dict("os.environ", AIRFLOW_CONN_TEST_CONN=Connection(**connection_kwargs).get_uri()),
+            mock.patch("airflow.providers.snowflake.hooks.snowflake.connector") as mock_connector,
+        ):
+            hook = SnowflakeHook(snowflake_conn_id="test_conn")
+            hook.get_conn()
+
+            call_args = mock_connector.connect.call_args[1]
+            assert call_args["proxy_host"] == "proxy.example.com"
+            assert call_args["proxy_port"] == 8080
+            assert call_args["proxy_user"] == "proxy_user"
+            assert call_args["proxy_password"] == "proxy_pass"
+
+    def test_sqlalchemy_uri_excludes_proxy_params(self):
+        """Test that proxy parameters are excluded from SQLAlchemy URI."""
+        connection_kwargs = deepcopy(BASE_CONNECTION_KWARGS)
+        connection_kwargs["extra"]["proxy_host"] = "proxy.example.com"
+        connection_kwargs["extra"]["proxy_port"] = "8080"
+
+        with mock.patch.dict("os.environ", AIRFLOW_CONN_TEST_CONN=Connection(**connection_kwargs).get_uri()):
+            hook = SnowflakeHook(snowflake_conn_id="test_conn")
+            uri = hook.get_uri()
+
+            # Proxy parameters should NOT appear in the URI
+            assert "proxy_host" not in uri
+            assert "proxy_port" not in uri
+            assert "proxy.example.com" not in uri
+            assert "8080" not in uri
+
+    def test_get_sqlalchemy_engine_with_proxy(self):
+        """Test get_sqlalchemy_engine does not include proxy params in URI but passes to connect_args if needed."""
+        connection_kwargs = deepcopy(BASE_CONNECTION_KWARGS)
+        connection_kwargs["extra"]["proxy_host"] = "proxy.example.com"
+        connection_kwargs["extra"]["proxy_port"] = "8080"
+
+        with (
+            mock.patch.dict("os.environ", AIRFLOW_CONN_TEST_CONN=Connection(**connection_kwargs).get_uri()),
+            mock.patch("airflow.providers.snowflake.hooks.snowflake.create_engine") as mock_create_engine,
+        ):
+            hook = SnowflakeHook(snowflake_conn_id="test_conn")
+            hook.get_sqlalchemy_engine()
+
+            # Check that the URI doesn't contain proxy params
+            called_uri = mock_create_engine.call_args[0][0]
+            assert "proxy_host" not in str(called_uri)
